==> pde-2.19.0.tgz: package/lib/adapters/default.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";

var DefaultAdapter = /*#__PURE__*/function () {
  function DefaultAdapter() {}

  var _proto = DefaultAdapter.prototype;

  _proto.getEnabledFeatures = function getEnabledFeatures(_ref) {
    var attributes = _ref.attributes;
    return [];
  };

  _proto.getInitialData = function getInitialData() {
    return null;
  };

  _proto.activateExperiment = function activateExperiment() {
    return null;
  };

  _proto.getVariation = function getVariation() {
    return null;
  };

  _proto.updateConsents = function updateConsents() {
    return null;
  };

  _proto.onReady = /*#__PURE__*/function () {
    var _onReady = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              return _context.abrupt("return", true);

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    function onReady() {
      return _onReady.apply(this, arguments);
    }

    return onReady;
  }();

  _proto.isFeatureEnabled = function isFeatureEnabled() {
    return false;
  };

  _proto.getAllFeatureVariables = function getAllFeatureVariables() {
    return {};
  };

  return DefaultAdapter;
}();

export { DefaultAdapter as default };

==> pde-2.26.0.tgz: package/lib/adapters/default.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
var DefaultAdapter = /*#__PURE__*/function () {
  function DefaultAdapter() {}
  var _proto = DefaultAdapter.prototype;
  _proto.getEnabledFeatures = function getEnabledFeatures(_ref) {
    var attributes = _ref.attributes;
    return [];
  };
  _proto.getInitialData = function getInitialData() {
    return null;
  };
  _proto.activateExperiment = function activateExperiment() {
    return null;
  };
  _proto.getVariation = function getVariation() {
    return null;
  };
  _proto.decide = function decide() {
    return null;
  };
  _proto.updateConsents = function updateConsents() {
    return null;
  };
  _proto.onReady = /*#__PURE__*/function () {
    var _onReady = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", true);
          case 1:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    function onReady() {
      return _onReady.apply(this, arguments);
    }
    return onReady;
  }();
  _proto.isFeatureEnabled = function isFeatureEnabled() {
    return false;
  };
  _proto.getAllFeatureVariables = function getAllFeatureVariables() {
    return {};
  };
  return DefaultAdapter;
}();
export { DefaultAdapter as default };
